@@ -1,6 +1,5 @@
 import io
 import json
-from snappi_trex.validation import Validation
 
 class Capture(object):
 
@@ -37,4 +36,7 @@ class Capture(object):
             self._client.fetch_capture_packets(self._captures[port_idx]['id'], pkt_list)
             for pkt in pkt_list:
                 res.write(pkt['binary'])
-        return res
\ No newline at end of file
+        return res
+
+    def is_started(self, port_id):
+        return port_id in self._captures
\ No newline at end of file
