@@ -7,7 +7,7 @@ class Metrics(object):
         self._client = trexclient
 
 
-    def get_metrics(self, request, port_ids, capture):
+    def get_port_metrics(self, request, port_ids, capture, link):
         req = json.loads(request.serialize())
         mc = Util.get_metrics_columns()
 
@@ -17,14 +17,14 @@ class Metrics(object):
             for p_name in req['port']['port_names']:
                 ports.append(port_ids.index(p_name))
 
-        col_names = ['location', 'link', 'capture', 'frames_tx', 'frames_rx',
+        col_names = ['link', 'capture', 'frames_tx', 'frames_rx',
                     'bytes_tx', 'bytes_rx', 'frames_tx_rate', 'frames_rx_rate', 
                     'bytes_tx_rate', 'bytes_rx_rate']
         if req['port']['column_names'] is not None:
             col_names = req['port']['column_names']
 
         metrics = self._client.get_stats(ports=ports)
-        res = []
+        port_metrics  = []
         for p in ports:
             m = {}
             m['name'] = port_ids[p]
@@ -34,12 +34,18 @@ class Metrics(object):
                 if capture.is_started(p):
                     m['capture'] = 'started'
 
+            if 'link' in col_names:
+                m['link'] = 'down'
+                if link.is_up(p):
+                    m['link'] = 'up'
+
             metrics_p = metrics[p]
             for col in mc:
                 if col in col_names:
                     metric_name_trex = mc[col]
                     m[col] = metrics_p[metric_name_trex]
 
-            res.append(m)
-        return res
+            port_metrics.append(m)
+
+        return port_metrics
      
\ No newline at end of file
