@@ -84,73 +84,55 @@ class SetConfig:
         layer_cnt = {} # Counts the occurrences of each layer type
         for header in packet_headers:
 
-            # ETHERNET HEADER FIELDS CONFIGURATION
-            if header['choice'] == 'ethernet':
-                pkt_headers.append(Ether()); layers.append('Ether')
-                layer_cnt['Ether'] = layer_cnt['Ether']+1 if 'Ether' in layer_cnt else 1
+            header_name = header['choice']
+            scapy_header = header_info[header_name]['scapy_name']
 
-                for field in header['ethernet']:
-                    field_info = header_info['ethernet'][field]
-                    vm_cmds += ValueOptions.get_value_cmds(
-                        layer_type='Ethernet', 
-                        layer_cnt=layer_cnt['Ether'], 
-                        header_field=header['ethernet'][field], 
-                        length=field_info['length'], 
-                        field_str=field_info['field_str'],
-                        bit_fixup=field_info['bit_fixup']
-                    )
+
+            # ETHERNET HEADER 
+            if header['choice'] == 'ethernet':
+                pkt_headers.append(Ether()); layers.append('Ethernet')
+                layer_cnt['Ethernet'] = layer_cnt['Ethernet']+1 if 'Ethernet' in layer_cnt else 1
+
+            # VLAN HEADER 
+            if header['choice'] == 'vlan':
+                pkt_headers.append(Dot1Q()); layers.append('Dot1Q')
+                layer_cnt['Dot1Q'] = layer_cnt['Dot1Q']+1 if 'Dot1Q' in layer_cnt else 1
+
+            # ARP HEADER 
+            elif header['choice'] ==  'arp':
+                pkt_headers.append(ARP()); layers.append('ARP')
+                layer_cnt['ARP'] = layer_cnt['ARPC']+1 if 'ARP' in layer_cnt else 1
                 
-            # IPv4 HEADER FIELDS CONFIGURATION
+            # IPv4 HEADER 
             elif header['choice'] == 'ipv4':
                 pkt_headers.append(IP()); layers.append('IP')
                 layer_cnt['IP'] = layer_cnt['IP']+1 if 'IP' in layer_cnt else 1
 
-                for field in header['ipv4']:
-                    field_info = header_info['ipv4'][field]
-                    if field == 'priority':
-                        header_field = header['ipv4'][field]['raw']
-                    else:
-                        header_field = header['ipv4'][field]
-                    vm_cmds += ValueOptions.get_value_cmds(
-                        layer_type='IP', 
-                        layer_cnt=layer_cnt['IP'], 
-                        header_field=header_field, 
-                        length=field_info['length'], 
-                        field_str=field_info['field_str'],
-                        bit_fixup=field_info['bit_fixup']
-                    )
-
-            # UDP HEADER FIELDS CONFIGURATION
+            # UDP HEADER 
             elif header['choice'] == 'udp':
                 pkt_headers.append(UDP()); layers.append('UDP')
                 layer_cnt['UDP'] = layer_cnt['UDP']+1 if 'UDP' in layer_cnt else 1
 
-                for field in header['udp']:
-                    field_info = header_info['udp'][field]
-                    vm_cmds += ValueOptions.get_value_cmds(
-                        layer_type='UDP', 
-                        layer_cnt=layer_cnt['UDP'], 
-                        header_field=header['udp'][field], 
-                        length=field_info['length'], 
-                        field_str=field_info['field_str'],
-                        bit_fixup=field_info['bit_fixup']
-                    )
-
-            # TCP HEADER FIELDS CONFIGURATION
+            # TCP HEADER
             elif header['choice'] == 'tcp':
                 pkt_headers.append(TCP()); layers.append('TCP')
                 layer_cnt['TCP'] = layer_cnt['TCP']+1 if 'TCP' in layer_cnt else 1
 
-                for field in header['tcp']:
-                    field_info = header_info['tcp'][field]
-                    vm_cmds += ValueOptions.get_value_cmds(
-                        layer_type='TCP', 
-                        layer_cnt=layer_cnt['TCP'], 
-                        header_field=header['tcp'][field], 
-                        length=field_info['length'], 
-                        field_str=field_info['field_str'],
-                        bit_fixup=field_info['bit_fixup']
-                    )
+            # Now configure the header fields
+            for field in header[header_name]:
+                header_field = header[header_name][field]
+                if header_name == 'ipv4' and field == 'priority':
+                    header_field = header['ipv4'][field]['raw']
+
+                field_info = header_info[header_name][field]
+                vm_cmds += ValueOptions.get_value_cmds(
+                    layer_type=scapy_header, 
+                    layer_cnt=layer_cnt[scapy_header], 
+                    header_field=header_field, 
+                    length=field_info['length'], 
+                    field_str=field_info['field_str'],
+                    bit_fixup=field_info['bit_fixup']
+                )
             
         return vm_cmds, pkt_headers, layers
 
