@@ -5,6 +5,7 @@ from snappi_trex.validation import Validation
 from snappi_trex.setconfig import SetConfig
 from snappi_trex.capture import Capture
 from snappi_trex.metrics import Metrics
+from snappi_trex.link import Link
 
 
 class Api(snappi.Api):
@@ -36,6 +37,7 @@ class Api(snappi.Api):
         self._transmit_states = {}
         self._capture = Capture(self._c)
         self._metrics = Metrics(self._c)
+        self._link = Link(self._c)
 
         try:
             # connect to server
@@ -71,7 +73,6 @@ class Api(snappi.Api):
         # Create response
         res = {'warnings': []}
 
-        # print(config.serialize())
         self._config = config
         cfg_obj = json.loads(self._config.serialize())
         self._loadPorts()
@@ -130,6 +131,7 @@ class Api(snappi.Api):
     def set_transmit_state(self, payload):
         """Set the transmit state of flows
         """
+        Validation.validate_transmit(payload, self._config)
         ts = json.loads(payload.serialize())
         cfg_obj = json.loads(self._config.serialize())
         ports = list(range(len(self._port_ids)))
@@ -184,17 +186,7 @@ class Api(snappi.Api):
 
     def set_link_state(self, payload):
         Validation.validate_link(payload, self._port_ids)
-        ls = json.loads(payload.serialize())
-        ports = list(range(len(self._port_ids)))
-        if ls['port_names'] is not None:
-            ports = []
-            for p_name in ls['port_names']:
-                ports.append(self._port_ids.index(p_name))
-
-        if ls['state'] == 'up':
-            self._c.set_port_attr(ports=ports, link_up=True)
-        elif ls['state'] == 'down':
-            self._c.set_port_attr(ports=ports, link_up=False)
+        self._link.set_link(payload, self._port_ids)
 
     
     def set_capture_state(self, payload):
@@ -216,19 +208,12 @@ class Api(snappi.Api):
         
 
     def get_metrics(self, request):
-        """
-        Gets port, flow and protocol metrics.
-
-        Args
-        ----
-        - request (Union[MetricsRequest, str]): A request for Port, Flow and
-          protocol metrics.
-          The request content MUST be vase on the OpenAPI model,
-          #/components/schemas/Result.MetricsRequest
-          See the docs/openapi.yaml document for all model details
+        """Gets port, flow and protocol metrics.
         """
         Validation.validate_metrics_request(request, self._port_ids)
-        return self._metrics.get_metrics(request, self._port_ids, self._capture)
+        response_obj = {'choice': 'port_metrics'}
+        response_obj['port_metrics'] = self._metrics.get_port_metrics(request, self._port_ids, self._capture, self._link)
+        return self.metrics_response().deserialize(response_obj)
 
 
     def get_config(self):
