@@ -49,16 +49,26 @@ class Util:
                     continue
                 result += int(e, 16)
             return result
+
+        if layer_type == 'ARP':
+            if len(value.split('.')) == 4:
+                return Util.convert_to_long(value, 'IP')
+            elif len(value.split(':')) == 6:
+                return Util.convert_to_long(value, 'Ethernet')
+            else:
+                raise SyntaxError()
         
         return value
 
     def get_header_info():
         return {
             "ethernet": {
+                "scapy_name": "Ethernet",
                 "src": {"field_str": "src", "length": 48, "bit_fixup": 0},
                 "dst": {"field_str": "dst", "length": 48, "bit_fixup": 0}
             },
             "ipv4": {
+                "scapy_name": "IP",
                 "src": {"field_str": "src", "length": 32, "bit_fixup": 0},
                 "dst": {"field_str": "dst", "length": 32, "bit_fixup": 0},
                 "version": {"field_str": "version", "length": 4, "bit_fixup": 0},
@@ -74,11 +84,13 @@ class Util:
                 "protocol": {"field_str": "proto", "length": 8, "bit_fixup": 0}
             },
             "udp": {
+                "scapy_name": "UDP",
                 "src_port": {"field_str": "sport", "length": 16, "bit_fixup": 0},
                 "dst_port": {"field_str": "dport", "length": 16, "bit_fixup": 0},
                 "length": {"field_str": "len", "length": 16, "bit_fixup": 0}
             },
             "tcp": {
+                "scapy_name": "TCP",
                 "src_port": {"field_str": "sport", "length": 16, "bit_fixup": 0},
                 "dst_port": {"field_str": "dport", "length": 16, "bit_fixup": 0},
                 "seq_num": {"field_str": "seq", "length": 32, "bit_fixup": 0},
@@ -94,6 +106,25 @@ class Util:
                 "ctl_syn": {"field_str": "flags", "length": 1, "bit_fixup": 14},
                 "ctl_fin": {"field_str": "flags", "length": 1, "bit_fixup": 15},
                 "window": {"field_str": "window", "length": 16, "bit_fixup": 0}
+            },
+            "arp": {
+                "scapy_name": "ARP",
+                "hardware_type": {"field_str": "hwtype", "length": 16, "bit_fixup": 0},
+                "protocol_type": {"field_str": "ptype", "length": 16, "bit_fixup": 0},
+                "hardware_length": {"field_str": "hwlen", "length": 8, "bit_fixup": 0},
+                "protocol_length": {"field_str": "plen", "length": 8, "bit_fixup": 0},
+                "operation": {"field_str": "op", "length": 16, "bit_fixup": 0},
+                "sender_hardware_addr": {"field_str": "hwsrc", "length": 48, "bit_fixup": 0},
+                "sender_protocol_addr": {"field_str": "psrc", "length": 32, "bit_fixup": 0},
+                "target_hardware_addr": {"field_str": "hwdst", "length": 48, "bit_fixup": 0},
+                "target_protocol_addr": {"field_str": "pdst", "length": 32, "bit_fixup": 0}
+            },
+            "vlan": {
+                "scapy_name": "Dot1Q",
+                "priority": {"field_str": "prio", "length": 3, "bit_fixup": 0},
+                "cfi": {"field_str": "id", "length": 1, "bit_fixup": 3},
+                "id": {"field_str": "vlan", "length": 12, "bit_fixup": 4},
+                "tpid": {"field_str": "type", "length": 16, "bit_fixup": 0}
             }
         }
 
