@@ -3,7 +3,8 @@ from snappi_trex.util import Util
 
 class Validation(object):
     """This class contains functions to validate the input of various
-    configuration components
+    configuration components. It will throw a SnappiTrexException for any
+    invalid inputs that it detects.
     """
     
     def validate_rate(rate):
@@ -47,7 +48,7 @@ class Validation(object):
             raise SnappiTrexException('T-Rex does not support fixed_seconds duration choice')
 
         elif duration['choice'] == 'continuous':
-            """"""
+            pass
 
         elif duration['choice'] == 'burst':
             if 'inter_burst_gap' in duration['burst']:
@@ -69,42 +70,28 @@ class Validation(object):
     def validate_packet(packet_headers):
         header_info = Util.get_header_info()
         for header in packet_headers:
-            if header['choice'] == 'ethernet':
-                for field in header['ethernet']:
-                    if field not in header_info['ethernet']:
-                        raise SnappiTrexException('\'{}\' is not a supported Ethernet field'.format(field))
-                    field_info = header_info['ethernet'][field]
-                    Validation.validate_value_option(header['ethernet'][field], 'Ethernet', field_info['length'])
-                
-            elif header['choice'] == 'ipv4':
-                for field in header['ipv4']:
-                    if field not in header_info['ipv4']:
-                        raise SnappiTrexException('\'{}\' is not a supported IPv4 field'.format(field))
-                    field_info = header_info['ipv4'][field]
-                    if field == 'priority':
+
+            header_name = header['choice']
+            scapy_header = header_info[header_name]['scapy_name']
+
+            if header_name not in header_info:
+                raise SnappiTrexException('Invalid packet \'header\' choice')
+            else:
+                for field in header[header_name]:
+                    if field not in header_info[header_name]:
+                        raise SnappiTrexException('\'{0}\' is not a supported \'{1}\' field'.format(field, header_name))
+                    field_info = header_info[header_name][field]
+                    header_field = header[header_name][field]
+                    if header_name == 'ipv4' and field == 'priority':
                         if 'raw' not in header['ipv4']['priority']:
                             raise SnappiTrexException('ipv4 \'priority\' only supports \'raw\' option')
                         header_field = header['ipv4'][field]['raw']
-                    else:
-                        header_field = header['ipv4'][field]
-                    Validation.validate_value_option(header_field, 'IP', field_info['length'])
+                    Validation.validate_value_option(
+                        header_field=header_field,
+                        layer_type=scapy_header,
+                        length=field_info['length']
+                    )
 
-            elif header['choice'] == 'udp':
-                for field in header['udp']:
-                    if field not in header_info['udp']:
-                        raise SnappiTrexException('\'{}\' is not a supported UDP field'.format(field))
-                    field_info = header_info['udp'][field]
-                    Validation.validate_value_option(header['udp'][field], 'UDP', field_info['length'])
-
-            elif header['choice'] == 'tcp':
-                for field in header['tcp']:
-                    if field not in header_info['tcp']:
-                        raise SnappiTrexException('\'{}\' is not a supported TCP field'.format(field))
-                    field_info = header_info['tcp'][field]
-                    Validation.validate_value_option(header['tcp'][field], 'TCP', field_info['length'])
-
-            else:
-                raise SnappiTrexException('Invalid packet \'header\' choice')
 
     def validate_size(f_size):
         if f_size['choice'] == 'increment':
@@ -171,10 +158,25 @@ class Validation(object):
                 error = True
         except ValueError as e:
             error = True
+        except SyntaxError as e:
+            error = True
         if error:
             raise SnappiTrexException('{0} is not a valid {1} address'.format(addr, layer_type))
 
 
+    def validate_transmit(payload, config):
+        all_flows = []
+        for f in config.flows:
+            all_flows.append(f.name)
+
+        if payload.flow_names is not None:
+            for f in payload.flow_names:
+                if f not in all_flows:
+                    raise SnappiTrexException('{} is an unrecognized flow name'.format(f))
+        if (payload.state != 'start') and (payload.state != 'stop') and (payload.state != 'pause'):
+            raise SnappiTrexException('{} is not a valid transmit state'.format(payload.state))
+
+
     def validate_capture(payload, port_ids):
         if payload.port_names is not None:
             for p_name in payload.port_names:
@@ -207,7 +209,7 @@ class Validation(object):
                 if p_name not in port_ids:
                     raise SnappiTrexException('\'{}\' is not a recognized port'.format(p_name))
 
-        col_names = ['capture', 'frames_tx', 'frames_rx',
+        col_names = ['link', 'capture', 'frames_tx', 'frames_rx',
                     'bytes_tx', 'bytes_rx', 'frames_tx_rate', 'frames_rx_rate', 
                     'bytes_tx_rate', 'bytes_rx_rate']
         if request.port.column_names is not None:
